/* This file is part of KNemo
   Copyright (C) 2004 Percy Leonhardt <percy@eris23.de>

   KNemo is free software; you can redistribute it and/or modify
   it under the terms of the GNU Library General Public License as
   published by the Free Software Foundation; either version 2 of
   the License, or (at your option) any later version.

   KNemo is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#include <qwidget.h>

#include <kdebug.h>
#include <kglobal.h>
#include <klocale.h>
#include <kaboutdata.h>
#include <kpopupmenu.h>
#include <kiconloader.h>
#include <kapplication.h>
#include <kaboutapplication.h>
#include <kactioncollection.h>

#include "interfacetray.h"

static const char description[] =
   I18N_NOOP( "KNemo - the KDE Network Monitor" );

static const char version[] = "0.1.10";

InterfaceTray::InterfaceTray( const QString& ifname,
                              QWidget* parent, const char* name )
    : KSystemTray( parent, name )
{
    actionCollection()->clear(); // remove the quit entry

    KPopupMenu* popup = contextMenu();
    int id = popup->idAt( 0 );
    popup->changeTitle( id, SmallIcon( "network_local.png" ),
                        "KNemo - " + ifname );
    popup->insertItem( SmallIcon( "network_local" ),
                       i18n( "&About KNemo" ), this,
                       SLOT( showAboutDialog() ) );
    popup->insertItem( i18n( "&Report Bug..." ), this,
                       SLOT( showReportBugDialog() ) );
    popup->insertSeparator();
    popup->insertItem( SmallIcon( "configure" ),
                       i18n( "&Configure KNemo..." ), this,
                       SIGNAL( configSelected() ) );
    mStartId = popup->insertItem( SmallIcon( "connect_established" ),
                                  "", this, SIGNAL( startCommandSelected() ) );
    mStopId = popup->insertItem( SmallIcon( "connect_no" ),
                                 "", this, SIGNAL( stopCommandSelected() ) );
}

InterfaceTray::~InterfaceTray()
{
}

void InterfaceTray::mousePressEvent( QMouseEvent* e )
{
    if ( !rect().contains( e->pos() ) )
        return;

    switch( e->button() )
    {
    case LeftButton:
        emit clicked();
        break;
    case MidButton:
    case RightButton:
        KSystemTray::mousePressEvent( e );
        break;
    default:
        break;
    }
}

void InterfaceTray::showAboutDialog()
{
    KAboutData data ( "knemo", I18N_NOOP( "KNemo" ), version,
                      description, KAboutData::License_GPL,
                      "(c) 2004, Percy Leonhardt", 0, 0,
                      "percy@eris23.de" );
    data.addAuthor( "Percy Leonhardt", I18N_NOOP( "Author" ),
                    "percy@eris23.de" );
    data.addAuthor( "Bernd Zimmer", I18N_NOOP( "German translation" ),
                    "berndzimmer@gmx.de" );
    data.addAuthor( "Raul Moratalla", I18N_NOOP( "Spanish translation" ),
                    "raul.moratalla@ono.com" );
    data.addAuthor( "Pedro Jurado Maqueda", I18N_NOOP( "Spanish translation" ),
                    "melenas@kdehispano.org" );
    data.addAuthor( "Malin Malinov", I18N_NOOP( "Bulgarian translation" ),
                    "lgmim@club-35.com" );

    KAboutApplication about( &data );
#if KDE_IS_VERSION(3,2,90) // cvs
    about.setIcon( KGlobal::iconLoader()->iconPath( "network_local", -1 ) );
#else
    about.setIcon( SmallIcon( "network_local" ) );
#endif
    about.exec();
}

void InterfaceTray::showReportBugDialog()
{
    kapp->invokeMailer( "percy@eris23.de", i18n( "Bug report for" ) +
                        " KNemo " + version );
}

#include "interfacetray.moc"
